@@ -26,6 +26,7 @@ from semantic_release.enums import LevelBump
 from semantic_release.errors import (
     BuildDistributionsError,
     GitCommitEmptyIndexError,
+    InternalError,
     UnexpectedResponse,
 )
 from semantic_release.gitproject import GitProject
@@ -35,7 +36,6 @@ from semantic_release.version.algorithm import (
     tags_and_versions,
 )
 from semantic_release.version.translator import VersionTranslator
-from semantic_release.version.version import Version
 
 if TYPE_CHECKING:  # pragma: no cover
     from pathlib import Path
@@ -45,6 +45,7 @@ if TYPE_CHECKING:  # pragma: no cover
 
     from semantic_release.cli.cli_context import CliContextObj
     from semantic_release.version.declaration import VersionDeclarationABC
+    from semantic_release.version.version import Version
 
 
 log = logging.getLogger(__name__)
@@ -64,7 +65,7 @@ def is_forced_prerelease(
     log.debug(
         "%s: %s",
         is_forced_prerelease.__name__,
-        ", ".join(f"{k} = {v}" for k, v in local_vars),
+        str.join(", ", iter(f"{k} = {v}" for k, v in local_vars)),
     )
     return (
         as_prerelease
@@ -90,7 +91,18 @@ def version_from_forced_level(
 
     # If we have no tags, return the default version
     if not ts_and_vs:
-        return Version.parse(DEFAULT_VERSION).bump(forced_level_bump)
+        # Since the translator is configured by the user, we can't guarantee that it will
+        # be able to parse the default version. So we first cast it to a tag using the default
+        # value and the users configured tag format, then parse it back to a version object
+        default_initial_version = translator.from_tag(
+            translator.str_to_tag(DEFAULT_VERSION)
+        )
+        if default_initial_version is None:
+            # This should never happen, but if it does, it's a bug
+            raise InternalError(
+                "Translator was unable to parse the embedded default version"
+            )
+        return default_initial_version.bump(forced_level_bump)
 
     _, latest_version = ts_and_vs[0]
     if forced_level_bump is not LevelBump.PRERELEASE_REVISION:
@@ -516,12 +528,8 @@ def version(  # noqa: C901
     gha_output.version = new_version
     ctx.call_on_close(gha_output.write_if_possible)
 
-    # Make string variant of version && Translate to tag if necessary
-    version_to_print = (
-        str(new_version)
-        if not print_only_tag
-        else translator.str_to_tag(str(new_version))
-    )
+    # Make string variant of version or appropriate tag as necessary
+    version_to_print = str(new_version) if not print_only_tag else new_version.as_tag()
 
     # Print the new version so that command-line output capture will work
     click.echo(version_to_print)
@@ -653,6 +661,7 @@ def version(  # noqa: C901
         project.git_tag(
             tag_name=new_version.as_tag(),
             message=new_version.as_tag(),
+            isotimestamp=commit_date.isoformat(),
             noop=opts.noop,
         )
 
@@ -690,13 +699,31 @@ def version(  # noqa: C901
         log.info("Remote does not support releases. Skipping release creation...")
         return
 
+    license_cfg = runtime.project_metadata.get(
+        "license-expression",
+        runtime.project_metadata.get(
+            "license",
+            "",
+        ),
+    )
+
+    if not isinstance(license_cfg, (str, dict)) or license_cfg is None:
+        license_cfg = ""
+
+    license_name = (
+        license_cfg.get("text", "")
+        if isinstance(license_cfg, dict)
+        else license_cfg or ""
+    )
+
     release_notes = generate_release_notes(
         hvcs_client,
-        release_history.released[new_version],
-        runtime.template_dir,
+        release=release_history.released[new_version],
+        template_dir=runtime.template_dir,
         history=release_history,
         style=runtime.changelog_style,
         mask_initial_release=runtime.changelog_mask_initial_release,
+        license_name=license_name,
     )
 
     exception: Exception | None = None
